SystemOrganization addCategory: #'AL-Tests-Http'!

TestCase subclass: #ALClientTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AL-Tests-Http'!

!ALClientTest methodsFor: 'as yet unclassified' stamp: 'cwp 9/8/2011 15:41'!
okResponse
	^ ('HTTP/1.1 200 OK<1s>Content-Type: text/plain; charset=ASCII<1s>Content-Length: 2<1s><1s>OK'
		expandMacrosWith: String crlf) asByteArray! !

!ALClientTest methodsFor: 'as yet unclassified' stamp: 'cwp 9/5/2011 12:56'!
testAnswersResponse
	| client answer |
	client := ALClient host: 'localhost' port: 80 in: self okResponse reading out: nil writing.
	answer := client sendRequest: (ALRequest method: 'GET' path: ALPath root).
	self assert: (answer isKindOf: ALResponse)! !

!ALClientTest methodsFor: 'as yet unclassified' stamp: 'cwp 9/3/2011 23:59'!
testCreationWithHostPort
	| client |
	client := ALClient host: 'localhost' port: 80.
	self assert: client host = 'localhost'.
	self assert: client port = 80.
	self deny: client isConnected.
	! !

!ALClientTest methodsFor: 'as yet unclassified' stamp: 'cwp 9/4/2011 00:19'!
testCreationWithStreams
	| client |
	client := ALClient host: 'localhost' port: 80 in: [0] reading out: nil writing.
	self assert: client host = 'localhost'.
	self assert: client port = 80.
	self assert: client isConnected.
	! !

!ALClientTest methodsFor: 'as yet unclassified' stamp: 'cwp 9/6/2011 15:46'!
testGet
	| client content |
	client := ALClient host: 'localhost' port: 80 in: self okResponse reading out: nil writing.
	content := client get: ALPath root.
	self assert: content = 'OK'! !

!ALClientTest methodsFor: 'as yet unclassified' stamp: 'cwp 9/6/2011 17:04'!
testHost
	| client message out |
	out := ByteArray new writing.
	client := ALClient host: 'localhost' port: 80 in: self okResponse reading out: out.
	client sendRequest: (ALRequest get: ALPath root).
	message := (out conclusion reading encoding: #latin1) rest.
	self assert: (message includesSubString: 'Host: localhost')! !

!ALClientTest methodsFor: 'as yet unclassified' stamp: 'cwp 9/7/2011 15:32'!
testReadEntity
	| client content response |
	client := ALClient host: 'localhost' port: 80 in: self okResponse reading out: nil writing.
	response := client sendRequest: (ALRequest get: ALPath root).
	response readEntityWith: [:in | content := in rest].
	self assert: content = 'OK'! !

!ALClientTest methodsFor: 'as yet unclassified' stamp: 'cwp 9/5/2011 12:56'!
testSendRequest
	| client out count |
	count := 0.
	out := [:byte | count := count + 1] writing.
	client := ALClient host: 'localhost' port: 80 in: self okResponse reading out: out.
	client sendRequest: (ALRequest method: 'GET' path: ALPath root).
	self assert: count > 0! !

TestCase subclass: #ALConnectionTest
	instanceVariableNames: 'connection handler'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AL-Tests-Http'!

!ALConnectionTest methodsFor: 'as yet unclassified' stamp: 'cwp 4/24/2011 21:59'!
handleRequest: aRequest
	^ handler value: aRequest! !

!ALConnectionTest methodsFor: 'support' stamp: 'cwp 3/20/2011 21:45'!
onRequest: aBlock
	| count |
	count := 0.
	handler := 
		[:request |
		count := count + 1.
		aBlock value: request].
	connection handleRequest.
	self assert: count > 0! !

!ALConnectionTest methodsFor: 'data' stamp: 'cwp 4/5/2011 20:24'!
request
	^ ByteArray new writing
		write: 'GET /griffle/plonk HTTP/1.1'; cr; lf;
		write: 'Host: localhost:8001'; cr; lf;
		write: 'Connection: keep-alive'; cr; lf;
		write: 'User-Agent: SUnit Test'; cr; lf;
		write: 'Accept: text/html;q=0.9,text/plain;q=0.8,image/png,*/*;q=0.5'; cr; lf;
		write: 'Accept-Encoding: gzip,deflate,sdch'; cr; lf;
		write: 'Accept-Language: en-US,en;q=0.8'; cr; lf;
		write: 'Accept-Charset: ISO-8859-1,utf-8;q=0.7,*;q=0.3'; cr; lf;
		cr; lf;
		conclusion! !

!ALConnectionTest methodsFor: 'as yet unclassified' stamp: 'cwp 5/4/2011 21:43'!
testParseChromeRequest

	connection := ALConnection 
		in: self request reading 
		out: ByteArray new writing
		application: self.
	self onRequest:
		[:request |
		self assert: request isMethodGet.
		self assert: request path = (ALPath / 'griffle' / 'plonk').
		self assert: request isConnectionKeepAlive.
		self thisIsATest]! !

!ALConnectionTest methodsFor: 'support' stamp: 'cwp 4/24/2011 22:00'!
thisIsATest
	^ ALResponse status: 204 reason: 'This is a test'.! !

TestCase subclass: #ALEntityTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AL-Tests-Http'!

!ALEntityTest methodsFor: 'as yet unclassified' stamp: 'cwp 9/8/2011 15:31'!
testPartialRead
	| entity stream |
	entity := ALEntity reading: #[1 2 3].
	entity filter limiting: 2.
	entity readWith: [:in | stream := in].
	self
		should: [stream get]
		raise: Incomplete! !

!ALEntityTest methodsFor: 'as yet unclassified' stamp: 'cwp 9/7/2011 15:15'!
testReadLimit
	| entity content |
	entity := ALEntity reading: #[1 2 3].
	entity filter limiting: 2.
	entity readWith: [:in | content := in rest].
	self assert: content = #[1 2]! !

!ALEntityTest methodsFor: 'as yet unclassified' stamp: 'cwp 9/5/2011 15:57'!
testReadUnlimited
	| entity content |
	entity := ALEntity reading: #[1 2 3].
	entity readWith: [:in | content := in rest].
	self assert: content = #[1 2 3]! !

!ALEntityTest methodsFor: 'as yet unclassified' stamp: 'cwp 9/8/2011 15:32'!
testWriteLimit
	| entity count |
	entity := ALEntity callback: 
		[:out | 
		out write: #[1 2].
		self should: [out put: 3] raise: Incomplete].
	entity filter limiting: 2.
	count := 0.
	entity writeInto: [:byte | count := count + 1] writing.
	self assert: count = 2.! !

TestCase subclass: #ALHttpMessageTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AL-Tests-Http'!

!ALHttpMessageTest methodsFor: 'as yet unclassified' stamp: 'cwp 9/9/2011 00:06'!
testContentType
	| response |
	response := ALResponse ok.
	response contentType: ALContentType html.
	self assert: (response rawHeader: 'Content-Type') class = ByteArray.
	self assert: (response contentType isKindOf: ALContentType)
	! !

!ALHttpMessageTest methodsFor: 'as yet unclassified' stamp: 'cwp 9/8/2011 11:12'!
testHeaderAnswersStrings
	| request |
	request := ALRequest get: ALPath root.
	request rawHeader: 'X-Testing' put: #[97 98 99].
	self assert: (request header: 'X-Testing') = 'abc'! !

!ALHttpMessageTest methodsFor: 'as yet unclassified' stamp: 'cwp 9/8/2011 11:02'!
testHeaderPutAcceptsBytes
	| request |
	request := ALRequest get: ALPath root.
	request header: 'X-Testing' put: #[97 98 99].
	self assert: (request header: 'X-Testing') = 'abc' ! !

!ALHttpMessageTest methodsFor: 'as yet unclassified' stamp: 'cwp 9/8/2011 10:59'!
testIsConnectionKeepAlive
	| request |
	request := ALRequest get: ALPath root.
	request beConnectionKeepAlive.
	self assert: (request header: 'Connection') isString.
	self assert: request isConnectionKeepAlive ! !

TestCase subclass: #ALHttpParserTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AL-Tests-Http'!

!ALHttpParserTest methodsFor: 'as yet unclassified' stamp: 'cwp 9/7/2011 16:06'!
testTextHtml
	| in parser result |
	in := 'text/html' asByteArray reading.
	parser := ALHttpParser on: in.
	result := parser parseContentType.
	self assert: (result isKindOf: ALContentType).
	self assert: (result type = 'text').
	self assert: (result subtype = 'html').
	self assert: result isText.
	self assert: result isHtml.! !

!ALHttpParserTest methodsFor: 'as yet unclassified' stamp: 'cwp 9/7/2011 16:09'!
testTypeSubtype
	| in parser result |
	in := 'image/jpeg' asByteArray reading.
	parser := ALHttpParser on: in.
	result := parser parseContentType.
	self assert: (result isKindOf: ALContentType).
	self assert: result type = 'image'.
	self assert: result subtype = 'jpeg'.
	self assert: result isImage.
	self assert: result isJpeg.! !

!ALHttpParserTest methodsFor: 'as yet unclassified' stamp: 'cwp 9/8/2011 14:15'!
testTypeSubtypeParameter
	| in parser result |
	in := 'text/html; charset=ISO-8859-4' asByteArray reading.
	parser := ALHttpParser on: in.
	result := parser parseContentType.
	self assert: (result isKindOf: ALContentType).
	self assert: (result type = 'text').
	self assert: (result subtype = 'html').
	self assert: result isText.
	self assert: result isHtml.
	self assert: result hasCharset.
	self assert: (result parameter: 'charset') = 'ISO-8859-4'.
	self assert: result charset = #'iso-8859-4'.! !

TestCase subclass: #ALHttpPrinterTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AL-Tests-Http'!

!ALHttpPrinterTest methodsFor: 'as yet unclassified' stamp: 'cwp 9/4/2011 02:01'!
testRootRequest
	| in printer request |
	in := ('GET / HTTP/1.1<1s>User-Agent: Altitude/0.1<1s>Accept: */*<1s><1s>' 
			expandMacrosWith: String crlf) reading.
	printer := ALHttpPrinter on: 
		[:byte || expected actual |
		actual := byte asCharacter.
		expected := in get asCharacter.
		self assert: actual  = expected] writing.
	request := ALRequest get: ALPath root.
	printer printRequest: request.
	self assert: in available = 0! !

TestCase subclass: #ALRelayTest
	instanceVariableNames: 'response'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AL-Tests-Http'!

ALRelayTest subclass: #ALLimitingRelayTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AL-Tests-Http'!

!ALLimitingRelayTest methodsFor: 'as yet unclassified' stamp: 'cwp 9/8/2011 23:55'!
testRequest
	| relay request |
	relay := ALLimitingRelay destination: self.
	request := ALRequest get: ALPath root.
	request contentLength: 3.
	request writeEntityWith: 
		[:out | 
		out write: #[1 2 3].
		self should: [out put: 4] raise: Incomplete].
	relay handleRequest: request.
	request writeEntityInto: ByteArray new writing.
! !

!ALLimitingRelayTest methodsFor: 'as yet unclassified' stamp: 'cwp 9/9/2011 00:16'!
testRequestNoContentLength
	| relay request |
	relay := ALLimitingRelay destination: self.
	request := ALRequest get: ALPath root.
	request writeEntityWith: 
		[:out | self shouldnt: [out write: #[1 2 3 4]] raise: Incomplete].
	relay handleRequest: request.
	request writeEntityInto: ByteArray new writing.
! !

!ALLimitingRelayTest methodsFor: 'as yet unclassified' stamp: 'cwp 9/9/2011 00:12'!
testResponse
	| relay result |
	relay := ALLimitingRelay destination: self.
	response := ALResponse ok.
	response contentLength: 3.
	response writeEntityWith: 
		[:out | 
		self shouldnt: [out write: #[1 2 3]] raise: Incomplete.
		self should: [out put: 4] raise: Incomplete]. 
	result := relay handleRequest: (ALRequest get: ALPath root).
	self assert: result == response.
	response writeEntityInto: ByteArray new writing.
! !

!ALLimitingRelayTest methodsFor: 'as yet unclassified' stamp: 'cwp 9/9/2011 00:15'!
testResponseNoContentLength
	| relay result |
	relay := ALLimitingRelay destination: self.
	response := ALResponse ok.
	response writeEntityWith: 
		[:out | self shouldnt: [out write: #[1 2 3 4]] raise: Incomplete].
	result := relay handleRequest: (ALRequest get: ALPath root).
	self assert: result == response.
	response writeEntityInto: ByteArray new writing.
! !

!ALRelayTest class methodsFor: 'as yet unclassified' stamp: 'cwp 9/8/2011 23:44'!
isAbstract
	^ self name = #ALRelayTest! !

!ALRelayTest methodsFor: 'as yet unclassified' stamp: 'cwp 9/9/2011 00:00'!
handleRequest: aRequest
	^ response! !

!ALRelayTest methodsFor: 'as yet unclassified' stamp: 'cwp 9/9/2011 00:02'!
setUp
	response := ALResponse status: 200 reason: 'OK'.! !

TestCase subclass: #ALRequestTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AL-Tests-Http'!

!ALRequestTest methodsFor: 'as yet unclassified' stamp: 'cwp 4/24/2011 20:48'!
testCreation
	| request |
	request := ALRequest method: 'GET' path: ALPath root.
	self assert: request method = 'GET'.
	self assert: request path = ALPath root.
	self assert: request version = 1.1s1.! !

TestCase subclass: #ALResponseTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AL-Tests-Http'!

!ALResponseTest methodsFor: 'as yet unclassified' stamp: 'cwp 4/24/2011 22:15'!
testCreation
	| response |
	response := ALResponse status: 204 reason: 'This is a test'.
	self assert: response status = 204.
	self assert: response reason = 'This is a test'.
	self assert: response version = 1.1s1
! !
